@@ -61,13 +61,6 @@ public:
 
   void                listen_open();
 
-  std::string         bind_address() const;
-  void                set_bind_address(const std::string& addr);
-
-  std::string         local_address() const;
-  void                set_local_address(const std::string& addr);
-
-  std::string         proxy_address() const;
   void                set_proxy_address(const std::string& addr);
 
   void                shutdown(bool force);
