@@ -43,7 +43,8 @@ namespace display {
 
 void
 TextElementList::clear() {
-  std::for_each(begin(), end(), [](TextElement* t) { delete t; });
+  for (auto t : *this)
+    delete t;
   base_type::clear();
 }
 
@@ -53,14 +54,14 @@ TextElementList::print(char* first, char* last, Canvas::attributes_list* attribu
 
   // Call print for each element even if first == last so that any
   // attributes gets added to the list.
-  for (iterator itr = begin(); itr != end(); ++itr)
+  for (auto& itr : *this)
     if (column-- > 0) {
       char* columnEnd = std::min(last, first + *m_columnWidth);
 
       if (columnEnd < first || columnEnd > last)
         throw torrent::internal_error("TextElementList::print(...) columnEnd < first || columnEnd > last.");
 
-      first = (*itr)->print(first, columnEnd, attributes, target);
+      first = itr->print(first, columnEnd, attributes, target);
 
       if (first > columnEnd)
         throw torrent::internal_error("TextElementList::print(...) first > columnEnd.");
@@ -69,7 +70,7 @@ TextElementList::print(char* first, char* last, Canvas::attributes_list* attribu
       first = columnEnd;
 
     } else {
-      first = (*itr)->print(first, last, attributes, target);
+      first = itr->print(first, last, attributes, target);
     }
 
   return first;
@@ -80,15 +81,15 @@ TextElementList::max_length() {
   extent_type length = 0;
   int column = m_columnWidth != NULL ? m_column : 0;
 
-  for (iterator itr = begin(); itr != end(); ++itr) {
-    extent_type l = column-- > 0 ? std::min((*itr)->max_length(), *m_columnWidth) : (*itr)->max_length();
+  for (auto& itr : *this) {
+    extent_type l = column-- > 0 ? std::min(itr->max_length(), *m_columnWidth) : itr->max_length();
 
     if (l == extent_full)
       return extent_full;
     
     length += l;
   }
-  
+
   return length;
 }
 
