@@ -56,8 +56,8 @@ PathInput::pressed(int key) {
     return TextInput::pressed(key);
 
   } else if (m_showNext) {
-    for (signal_void::iterator itr = m_signal_show_next.begin(), last = m_signal_show_next.end(); itr != last; itr++)
-      (*itr)();
+    for (auto& itr : m_signal_show_next)
+      itr();
 
   } else {
     receive_do_complete();
@@ -66,17 +66,6 @@ PathInput::pressed(int key) {
   return true;
 }
 
-struct _transform_filename {
-  void operator () (utils::directory_entry& entry) {
-#ifdef __sun__
-    if (entry.s_type & S_IFDIR)
-#else
-    if (entry.s_type == DT_DIR)
-#endif
-      entry.s_name += '/';
-  }
-};
-
 void
 PathInput::receive_do_complete() {
   lt_log_print(torrent::LOG_UI_EVENTS, "path_input: received completion");
@@ -91,7 +80,14 @@ PathInput::receive_do_complete() {
     return;
   }
 
-  std::for_each(dir.begin(), dir.end(), _transform_filename());
+  for (auto& entry : dir) {
+#ifdef __sun__
+    if (entry.s_type & S_IFDIR)
+#else
+    if (entry.s_type == DT_DIR)
+#endif
+      entry.s_name += '/';
+  }
 
   range_type r = find_incomplete(dir, str().substr(dirEnd, get_pos()));
 
@@ -116,8 +112,8 @@ PathInput::receive_do_complete() {
   if (m_showNext) {
     lt_log_print(torrent::LOG_UI_EVENTS, "path_input: show next page");
 
-    for (signal_itr_itr::iterator itr = m_signal_show_range.begin(), last = m_signal_show_range.end(); itr != last; itr++)
-      (*itr)(r.first, r.second);
+    for (auto& itr : m_signal_show_range)
+      itr(r.first, r.second);
   }
 }
 
